about summary refs log tree commit diff
path: root/src/libstd
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2014-11-20 16:02:03 +0000
committerbors <bors@rust-lang.org>2014-11-20 16:02:03 +0000
commit96c8f2b0c1846756e617f1f1fc1372c506e24248 (patch)
tree7aa5bc11c6c1f7ba90254432ba54c6fc6cf08980 /src/libstd
parent394269d16e3752a23ffa273e68f8aaefd2a510c4 (diff)
parent3f3b2d6b7ef68d3a3817804fa4dba849a74e6878 (diff)
auto merge of #19071 : huonw/rust/col2column, r=nikomatsakis
This macro is very rarely used, so there is no need (and it is better)
for it to avoid the abbreviation.

Closes rust-lang/rfcs#467.
Diffstat (limited to 'src/libstd')
-rw-r--r--src/libstd/macros.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/libstd/macros.rs b/src/libstd/macros.rs
index 4e5dd5d8818..18c109d92a0 100644
--- a/src/libstd/macros.rs
+++ b/src/libstd/macros.rs
@@ -557,17 +557,17 @@ pub mod builtin {
     /// A macro which expands to the column number on which it was invoked.
     ///
     /// The expanded expression has type `uint`, and the returned column is not
     /// the invocation of the `col!()` macro itself, but rather the first macro
     /// invocation leading up to the invocation of the `col!()` macro.
     ///
     /// # Example
     ///
     /// ```
-    /// let current_col = col!();
+    /// let current_col = column!();
     /// println!("defined on column: {}", current_col);
     /// ```
     #[macro_export]
-    macro_rules! col( () => ({ /* compiler built-in */ }) )
+    macro_rules! column( () => ({ /* compiler built-in */ }) )
 
     /// A macro which expands to the file name from which it was invoked.
     ///
@@ -557,17 +557,17 @@ pub mod builtin {
     ///
     /// The expanded expression has type `uint`, and the returned column is not
-    /// the invocation of the `col!()` macro itself, but rather the first macro
-    /// invocation leading up to the invocation of the `col!()` macro.
+    /// the invocation of the `column!()` macro itself, but rather the first macro
+    /// invocation leading up to the invocation of the `column!()` macro.
     ///
     /// # Example